Module workspaces_api

Module workspaces_api 

Enums

WorkspacesServiceDeleteError
struct for typed errors of method workspaces_service_delete
WorkspacesServiceGetMyWorkspaceError
struct for typed errors of method workspaces_service_get_my_workspace
WorkspacesServiceGetWorkspaceError
struct for typed errors of method workspaces_service_get_workspace
WorkspacesServicePublicGetWorkspaceError
struct for typed errors of method workspaces_service_public_get_workspace
WorkspacesServiceRequestEnrollmentError
struct for typed errors of method workspaces_service_request_enrollment
WorkspacesServiceUpdateError
struct for typed errors of method workspaces_service_update
WorkspacesServiceUpdateOriginInquiryError
struct for typed errors of method workspaces_service_update_origin_inquiry
WorkspacesServiceUpdateOriginPurposeError
struct for typed errors of method workspaces_service_update_origin_purpose

Functions

workspaces_service_delete
Soft-delete the workspace associated with the authenticated member’s session. This operation can be reversed by contacting support.
workspaces_service_get_my_workspace
Return the workspace associated with the authenticated member’s current session.
workspaces_service_get_workspace
Retrieve workspace details for the provided identifier, typically for internal tooling.
workspaces_service_public_get_workspace
Retrieve public information about a workspace that has been published.
workspaces_service_request_enrollment
Submit a request for workspace enrollment, setting the enroll_requested_at timestamp.
workspaces_service_update
Modify workspace settings such as the display name and MFA enforcement policy.
workspaces_service_update_origin_inquiry
Persist how a workspace discovered Linkbreakers without exposing the value to other workspace APIs.
workspaces_service_update_origin_purpose
Persist what the workspace wants to build with Linkbreakers for AI assistance without exposing the value to other workspace APIs.