Enums
- Workspaces
Service Delete Error - struct for typed errors of method
workspaces_service_delete - Workspaces
Service GetMy Workspace Error - struct for typed errors of method
workspaces_service_get_my_workspace - Workspaces
Service GetWorkspace Error - struct for typed errors of method
workspaces_service_get_workspace - Workspaces
Service Public GetWorkspace Error - struct for typed errors of method
workspaces_service_public_get_workspace - Workspaces
Service Request Enrollment Error - struct for typed errors of method
workspaces_service_request_enrollment - Workspaces
Service Update Error - struct for typed errors of method
workspaces_service_update - Workspaces
Service Update Origin Inquiry Error - struct for typed errors of method
workspaces_service_update_origin_inquiry - Workspaces
Service Update Origin Purpose Error - struct for typed errors of method
workspaces_service_update_origin_purpose
Functions
- workspaces_
service_ delete - Soft-delete the workspace associated with the authenticated member’s session. This operation can be reversed by contacting support.
- workspaces_
service_ get_ my_ workspace - Return the workspace associated with the authenticated member’s current session.
- workspaces_
service_ get_ workspace - Retrieve workspace details for the provided identifier, typically for internal tooling.
- workspaces_
service_ public_ get_ workspace - Retrieve public information about a workspace that has been published.
- workspaces_
service_ request_ enrollment - Submit a request for workspace enrollment, setting the enroll_requested_at timestamp.
- workspaces_
service_ update - Modify workspace settings such as the display name and MFA enforcement policy.
- workspaces_
service_ update_ origin_ inquiry - Persist how a workspace discovered Linkbreakers without exposing the value to other workspace APIs.
- workspaces_
service_ update_ origin_ purpose - Persist what the workspace wants to build with Linkbreakers for AI assistance without exposing the value to other workspace APIs.